colour.plotting.quality Module — Colour 0.3.0 documentation

# colour.plotting.quality Module

## Colour Quality Plotting

Defines the colour quality plotting objects:

- `colour_rendering_index_bars_plot()`

`colour.plotting.quality.` `colour_rendering_index_bars_plot`(*args, **kwargs)

  Plots the colour rendering index of given illuminant.

  Parameters: | illuminant (SpectralPowerDistribution) – Illuminant to plot the colour rendering index. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool

  Examples

      >>> from colour import ILLUMINANTS_RELATIVE_SPDS
      >>> illuminant = ILLUMINANTS_RELATIVE_SPDS.get('F2')
      >>> colour_rendering_index_bars_plot(illuminant)
      True